@@ -13,11 +13,7 @@ def competitions(competitions: list) -> dict:
 
 
 def matches(matches: list) -> dict:
-    matches_ = {
-        match["match_id"]: match
-        for match in matches
-        if match["match_status"] == "available"
-    }
+    matches_ = {match["match_id"]: match for match in matches}
     return matches_
 
 
@@ -33,7 +29,8 @@ def events(events: list, match_id: int) -> dict:
         events_[ev["id"]] = ev
     return events_
 
+
 def frames(frames: list, match_id: int) -> list:
     for fr in frames:
         fr["match_id"] = match_id
-    return frames
\ No newline at end of file
+    return frames
